﻿//===================================================================================================================
//  File:       Quote.cs
//  Author:     Dan Becker, Dave Langer 
//  Course:     CSS 590 A - Mobile Computing, Spring 2012
//===================================================================================================================
using System;

namespace ArchitectsUnited.Phix.Model
{
    /// <summary>
    /// a class to return a pithy quote about books for display on the main page of Phix
    /// </summary>
    /// 
    // Seems like I am taking the 'wrong' approach here - would be more idiomatic to 
    // have PhixViewModel contstruct the list of quotes once for the app session
    // and have PhixViewModel return a new quote when asked
    // instead of taking this approach to randomly build a new quote each time
    // but these string operations ought to be so cheap it doesn't have a practical effect
    // ....still, it makes me feel dirty and wrong. I should refactor this...
   // make it a static propoerty of the App object in App.xaml.cs
 
    public class Quote
    {
        #region Properties
        /// <summary> 
        /// text of the quote - should include surrounding curly quotes
        /// </summary>
        public string Text {get; private set;}

        /// <summary> 
        /// name of the quote's author / source - prefix with a hyphen or en-dash
        /// </summary>
        public string Source { get; private set; }
 
        #endregion


        #region Constructor
        /// <summary>
        /// Instantiate a random quote object
        /// </summary>
        /// 
        public Quote()
        { 
            // creating a new Random object each time is not recommended; best practice is create one
            // and call Next on it each time a new one is needed

            // Instantiate random number generator using system-supplied value as seed.
            Random rand = new Random();

            int numQuotes = 29; // should match the highest case number
            int randSwitch = rand.Next(numQuotes+1); // rand.Next(int) returns a random non-negative integer < int 

            switch (randSwitch)
            {
                case 0:
                    Text = "“This is not a novel to be tossed aside lightly. It should be thrown with great force.” ";
                    Source = "Dorothy Parker";
                    break;
                case 1:
                    Text = "“A room without books is like a body without a soul.”";
                    Source = "Marcus Tullius Cicero";
                    break;
                case 2:
                    Text = "“Outside of a dog, a book is man's best friend. Inside of a dog, it's too dark to read.”";
                    Source = "Groucho Marx";
                    break;
                case 3:
                    Text = "“I never travel without my diary. One should always have something sensational to read on the train.”";
                    Source = "Oscar Wilde";
                    break;
                case 4:
                    Text = "“A good book is the precious life-blood of a master spirit, embalmed and treasured up on purpose to a life beyond life.”";
                    Source = "John Milton";
                    break;
                case 5:
                    Text = "“Some books are lies frae end to end.”";
                    Source = "Robert Burns";
                    break;
                case 6:
                    Text = "“When I have a little money, I buy books; and if I have any left, I buy food and clothes.”";
                    Source = "Desiderius Erasmus";
                    break;
                case 7:
                    Text = "“If you only read the books that everyone else is reading, you can only think what everyone else is thinking”";
                    Source = "Haruki Murakami";
                    break;
                case 8:
                    Text = "“It is what you read when you don't have to that determines what you will be when you can't help it.”";
                    Source = "Oscar Wilde";
                    break;
                case 9:
                    Text = "“I declare after all there is no enjoyment like reading! How much sooner one tires of any thing than of a book! -- When I have a house of my own, I shall be miserable if I have not an excellent library.”";
                    Source = "Jane Austen";
                    break;
                case 10:
                    Text = "“Never trust anyone who has not brought a book with them.”";
                    Source = "Lemony Snicket";
                    break;
                case 11:
                    Text = "“You don't have to burn books to destroy a culture. Just get people to stop reading them.”";
                    Source = "Ray Bradbury";
                    break;
                case 12:
                    Text = "“The more that you read, the more things you will know. The more that you learn, the more places you'll go.”";
                    Source = "Dr. Seuss";
                    break;
                case 13:
                    Text = "“I have always imagined that Paradise will be a kind of library.” ";
                    Source = "Jorge Luis Borges";
                    break;
                case 14:
                    Text = "“You can never get a cup of tea large enough or a book long enough to suit me.” ";
                    Source = "C.S. Lewis";
                    break;
                case 15:
                    Text = "“There is no friend as loyal as a book.”";
                    Source = "Ernest Hemingway";
                    break;
                case 16:
                    Text = "“Books are the quietest and most constant of friends; they are the most accessible and wisest of counselors, and the most patient of teachers.”";
                    Source = "Charles William Eliot";
                    break;
                case 17:
                    Text = "“Do not read, as children do, to amuse yourself, or like the ambitious, for the purpose of instruction. No, read in order to live.”";
                    Source = "Gustave Flaubert";
                    break;
                case 18:
                    Text = "“Where is human nature so weak as in the bookstore?” ";
                    Source = "Henry Ward Beecher";
                    break;
                case 19:
                    Text = "“I cannot live without books.” ";
                    Source = "Thomas Jefferson";
                    break;
                case 20:
                    Text = "“There are two motives for reading a book; one, that you enjoy it; the other, that you can boast about it.”";
                    Source = "Bertrand Russell";
                    break;
                case 21:
                    Text = "“If there's a book that you want to read, but it hasn't been written yet, then you must write it.” ";
                    Source = "Toni Morrison";
                    break;
                case 22:
                    Text = "“She is too fond of books, and it has turned her brain.” ";
                    Source = "Louisa May Alcott";
                    break;
                case 23:
                    Text = "“Some books should be tasted, some devoured, but only a few should be chewed and digested thoroughly.” ";
                    Source = "Cornelia Funke";
                    break;
                case 24:
                    Text = "“A mind needs books as a sword needs a whetstone, if it is to keep its edge.” ";
                    Source = "George R.R. Martin";
                    break;
                case 25:
                    Text = "“Books are the perfect entertainment: no commercials, no batteries, hours of enjoyment for each dollar spent. What I wonder is why everybody doesn't carry a book around for those inevitable dead spots in life.” ";
                    Source = "Stephen King";
                    break;
                case 26:
                    Text = "“After nourishment, shelter and companionship, stories are the thing we need most in the world.” ";
                    Source = "Philip Pullman";
                    break;
                case 27:
                    Text = "“I do things like get in a taxi and say, ‘The library, and step on it.’” ";
                    Source = "David Foster Wallace";
                    break;
                case 28:
                    Text = "“You think your pain and your heartbreak are unprecedented in the history of the world, but then you read. It was books that taught me that the things that tormented me most were the very things that connected me with all the people who were alive, or who had ever been alive.” ";
                    Source = "James Baldwin";
                    break;
                case 29:
                    Text = "“I don't believe in the kind of magic in my books. But I do believe something very magical can happen when you read a good book.” ";
                    Source = "J.K. Rowling";
                    break;
                //case 12:
                //    Text = "";
                //    Source = "";
                //    break;
            }
        }
        #endregion
    }
}
