﻿//===================================================================================================================
//  File:       WorldCatSearchResult.cs
//  Author:     Dan Becker, Dave Langer 
//  Course:     CSS 590 A - Mobile Computing, Spring 2012
//===================================================================================================================
using System.Xml.Linq;
using System.Collections.Generic;

namespace ArchitectsUnited.Phix.Model
{
    /// <summary>
    /// Abstraction of a search result from the WorldCat Basic API
    /// </summary>
    public class WorldCatSearchResult
    {
        #region Constants

        // Search strigns for WorldCat Basic API ATOM XML
        private const string titleSearch = "{http://www.w3.org/2005/Atom}title";
        private const string oclcSearch = "{http://purl.org/oclc/terms/}recordIdentifier";
        private const string identifierSearch = "{http://purl.org/dc/elements/1.1/}identifier";
        private const string isbnSearch = "urn:ISBN:";

        #endregion


        #region Properties

        /// <summary>
        /// The WorldCat book title for the search result
        /// </summary>
        public string Title { get; private set; }

        /// <summary>
        /// The WorldCat book identifier for the search result
        /// </summary>
        public string OCLC { get; private set; }

        /// <summary>
        /// The collection of book ISBNs for the search result
        /// </summary>
        public IList<string> ISBNs { get; private set; }

        #endregion


        #region Constructor

        /// <summary>
        /// Constructor
        /// </summary>
        /// <param name="searchResult">An XElement object corresponding to an <entry/> element from a WorldCat Basic API
        /// ATOM document.</param>
        public WorldCatSearchResult(XElement searchResult)
        {
            ISBNs = new List<string>();

            // Grab the title from the XML
            Title = searchResult.Element(titleSearch).Value;

            // Grab the OCLC from the XML
            OCLC = searchResult.Element(oclcSearch).Value;

            // Gabe the ISBNs from the XML
            IEnumerable<XElement> isbns = searchResult.Elements(identifierSearch);

            foreach (XElement isbn in isbns)
            {
                // We only care about ISBNs, not LCCNs
                if (isbn.Value.Contains(isbnSearch))
                {
                    // Get only the actual ISBN
                    ISBNs.Add(isbn.Value.Replace(isbnSearch, ""));
                }
            }
        }

        #endregion 
    }
}
