﻿//===================================================================================================================
//  File:       LibraryMappedEvent.cs
//  Authors:    Dan Becker, Dave Langer 
//  Course:     CSS 590 A - Mobile Computing, Spring 2012
//===================================================================================================================
using System;

namespace ArchitectsUnited.Phix.ViewModel
{
    /// <summary>
    /// Custom event class raised by the ViewModel in response to an error condition (e.g., an exception raised
    /// during HTTP communitcation).
    /// </summary>
    public class ErrorEncounteredEvent : EventArgs
    {
        #region Public Enumeration

        /// <summary>
        /// Public enumeration providing metadata regarding the type of error encountered.
        /// </summary>
        public enum ErrorType
        {
            BingMaps,
            WorldCatSearch,
            GoogleSearch,
            BookNotFound,
            LibraryMap
        };

        #endregion


        #region Properties

        /// <summary>
        /// The type of error encountered.
        /// </summary>
        public ErrorType Type { get; private set; }

        /// <summary>
        /// User-friendly string describing the error encountered.
        /// </summary>
        public string Message { get; private set; }


        #endregion


        #region Constructor

        /// <summary>
        /// Constructor
        /// </summary>
        /// <param name="type">The type of error encountered.</param>
        /// <param name="message">User-friendly string describing the error encountered.</param>
        public ErrorEncounteredEvent(ErrorType type, string message)
        {
            Type = type;
            Message = message;
        }

        #endregion
    }
}
