﻿//===================================================================================================================
//  File:       MainPage.xaml.cs
//  Authors:    Dan Becker, Dave Langer 
//  Course:     CSS 590 A - Mobile Computing, Spring 2012
//===================================================================================================================
using System;
using System.Windows.Input;
using Microsoft.Phone.Controls;
using System.Windows.Media;

namespace ArchitectsUnited.Phix
{
    /// <summary>
    /// Implements the Presentation to display a search text box UI to the user.
    /// </summary>
    public partial class MainPage : PhoneApplicationPage
    {
        #region Constructo

        // Constructor
        public MainPage()
        {
            InitializeComponent();
        }

        #endregion


        #region Event Handlers

        /// <summary>
        ///  Event handler for changing the quote every time we load this page
        /// </summary>
        protected override void OnNavigatedTo(System.Windows.Navigation.NavigationEventArgs e)
        {
            Model.Quote mQuote = new Model.Quote();
            QuoteText.Text = mQuote.Text;
            QuoteSource.Text = mQuote.Source;
        }

        /// <summary>
        /// Event handler for the user opting to see the "About" page from the application bar
        /// </summary>
        private void ApplicationBarMenuItem_Click(object sender, EventArgs e)
        {
            NavigationService.Navigate(new Uri("/About", UriKind.Relative));
        }

        /// <summary>
        /// Event handler for the user tapping the search (i.e., magnifying glass) icon
        /// </summary>
        private void Search_ActionIconTapped(object sender, EventArgs e)
        {
            goSearch();
        }

        /// <summary>
        /// Event handler called for every tap of the keyboard
        /// </summary>
        private void searchTermBox_KeyDown(object sender, KeyEventArgs e)
        {
            // fixing glitch with PhoneTextBox where entered text turns to hint color
            // need to make sure we don't set the hint color to black so check for "no user-entered text" condition
            if (searchTermBox.Text != string.Empty)
            {
                searchTermBox.Foreground = new SolidColorBrush(Colors.Black);
            }

            // Per UX best practices, respond to the enter key as the cue to begin the search
            if (e.Key == Key.Enter)
            {
                goSearch();
            }
        }

        /// <summary>
        /// Event handler for when the search box gets focus in the UI
        /// </summary>
        private void searchTermBox_GotFocus(object sender, System.Windows.RoutedEventArgs e)
        {
            // part 2 of fixing glitch with PhoneTextBox where entered text turns to hint color
            searchTermBox.Foreground = new SolidColorBrush(Colors.Black);
        }

        #endregion


        #region Common Helper Methods

        /// <summary>
        /// Common helper method for initiating a search.
        /// </summary>
        private void goSearch()
        {
            // Don't let user search on an empty string
            if (searchTermBox.Text.Trim() != string.Empty) 
            {
                string destination = "/Views/BookSearchResults.xaml?q=";
                destination += searchTermBox.Text.Trim(); ;
                NavigationService.Navigate(new Uri(destination, UriKind.Relative));
            }
        }

        #endregion
    }
}