﻿//===================================================================================================================
//  File:       SellerPage.xaml.cs
//  Authors:    Dan Becker, Dave Langer 
//  Course:     CSS 590 A - Mobile Computing, Spring 2012
//===================================================================================================================
using System;
using System.Windows;
using Microsoft.Phone.Controls;

namespace ArchitectsUnited.Phix.Views
{
    /// <summary>
    /// Implements the Presentation to display the a WorldCat seller page for the selected book
    /// </summary>
    public partial class SellerPage : PhoneApplicationPage
    {
        #region Constants

        // The Query String parameter defined in the URI Mapper in App.xaml
        private const string uriKey = "URI";

        // String constants for book sellers
        private const string amazon = "amazon";
        private const string bnSearch = "barnesandnoble";
        private const string bnDisplay = "b & n";
        private const string betterWorldSearch = "betterworldbooks";
        private const string betterWorldDisplay = "better world";
        private const string googleSearch = "books.google.com";
        private const string googleDisplay = "google";
        private const string otherDisplay = "seller page";

        #endregion


        #region Constructor

        public SellerPage()
        {
            InitializeComponent();
        }

        #endregion


        #region Event Handlers

        /// <summary>
        /// Have browser control navigate to the WorldCat seller's page
        /// </summary>
        protected override void OnNavigatedTo(System.Windows.Navigation.NavigationEventArgs e)
        {
            // Hide the browser and message block
            browser.Visibility = Visibility.Collapsed;
            txtInvalidSellerURI.Visibility = Visibility.Collapsed;

            // Fire up progress bar
            txtLoadingSellerPage.Visibility = Visibility.Visible;
            ProgressBar.Visibility = Visibility.Visible;
            ProgressBar.IsIndeterminate = true;
            
            string sellerUri ;

            if (NavigationContext.QueryString.ContainsKey(uriKey))
            {
                // Unencode the path parameter for complex paths (e.g., Google Books)
                sellerUri = Uri.UnescapeDataString(NavigationContext.QueryString[uriKey]);

                // Update the UI with the seller name
                UpdateUIWithSellerName(sellerUri);

                // Load up the seller's page
                browser.Navigate(new Uri(sellerUri, UriKind.Absolute));
            }
            else
            {
                // No seller URI passed, display user-friendly message
                HideProgressBar();

                txtInvalidSellerURI.Visibility = Visibility.Visible;
            }

            base.OnNavigatedTo(e);
        }

        /// <summary>
        /// Event handler for when navigation of the browser to the seller page is completed. 
        /// </summary>
        private void BrowserNavigated(object sender, System.Windows.Navigation.NavigationEventArgs e)
        {
            HideProgressBar();

            // Show browser
            browser.Visibility = Visibility.Visible;
        }

        #endregion


        #region Common Helper Methods

        /// <summary>
        /// Helper method, see if seller URI is recognized and update the UI accordingly.
        /// </summary>
        /// <param name="sellerUri">The WorldCat URI string to use for browser navigation.</param>
        private void UpdateUIWithSellerName(string sellerUri)
        {
            if (sellerUri.Contains(amazon))
            {
                PageTitle.Text = amazon;
            }
            else if (sellerUri.Contains(bnSearch))
            {
                PageTitle.Text = bnDisplay;
            }
            else if (sellerUri.Contains(betterWorldSearch))
            {
                PageTitle.Text = betterWorldDisplay;
            }
            else if (sellerUri.Contains(googleSearch))
            {
                PageTitle.Text = googleDisplay;
            }
            else
            {
                PageTitle.Text = otherDisplay;
            }
        }

        /// <summary>
        /// Hide the UI cues to the user that asynchronous processing is happening.
        /// </summary>
        private void HideProgressBar()
        {
            // Turn off progress bars
            txtLoadingSellerPage.Visibility = Visibility.Collapsed;
            ProgressBar.Visibility = Visibility.Collapsed;
            ProgressBar.IsIndeterminate = false;
        }

        #endregion
    }
}